import grabDSQLConnection from "../../grab-dsql-connection";

/**
 * # DSQL user read-only DB handler
 * @requires DSQL_DB_CONN - Gobal Variable for Datasquirel Database
 */
export default async function DB_HANDLER(query: string, values?: any[]) {
    const CONNECTION = await grabDSQLConnection();

    try {
        if (!CONNECTION)
            throw new Error("No Connection provided to DB_HANDLER function!");

        const results = await CONNECTION.query(query, values);

        if (Array.isArray(results)) {
            return Array.from(results);
        } else {
            return results;
        }
    } catch (error: any) {
        global.ERROR_CALLBACK?.(`DB_HANDLER Error`, error as Error);
        return {
            success: false,
            error: error.message,
        };
    } finally {
        await CONNECTION?.end();
    }
}
