import grabDSQLConnection from "../../grab-dsql-connection";

/**
 * # DSQL user read-only DB handler
 */
export default async function NO_DB_HANDLER(query: string, values?: any[]) {
    const CONNECTION = await grabDSQLConnection();

    try {
        return new Promise((resolve, reject) => {
            CONNECTION.query(query, values)
                .then(async (results) => {
                    if (Array.isArray(results)) {
                        resolve(Array.from(results));
                    } else {
                        resolve(results);
                    }
                })
                .catch(async (err) => {
                    resolve({
                        error: err.message,
                        sql: err.sql,
                    });
                })
                .finally(async () => {
                    await CONNECTION?.end();
                });
        });
    } catch (error: any) {
        global.ERROR_CALLBACK?.(`NO_DB_HANDLER Error`, error as Error);
        return {
            success: false,
            error: error.message,
        };
    }
}
